@@ -33,17 +33,15 @@
 #include "nautilus-application.h"
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-main.h"
-#include "nautilus-services.h"
 #include "nautilus-sidebar.h"
 #include "nautilus-signaller.h"
 #include "nautilus-switchable-navigation-bar.h"
 #include "nautilus-window-manage-views.h"
-#include "nautilus-window-service-ui.h"
 #include "nautilus-zoom-control.h"
 #include <X11/Xatom.h>
 #include <bonobo/bonobo-exception.h>
+#include <bonobo/bonobo-property-bag-client.h>
 #include <bonobo/bonobo-ui-util.h>
-#include <ctype.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-generous-bin.h>
@@ -60,7 +58,6 @@
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-geometry.h>
 #include <libgnomeui/gnome-messagebox.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-window-icon.h>
@@ -69,6 +66,7 @@
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-drag-window.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-horizontal-splitter.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
@@ -82,7 +80,7 @@
 #include <math.h>
 #include <sys/time.h>
 
-/* FIXME bugzilla.eazel.com 1243: 
+/* FIXME bugzilla.gnome.org 41243: 
  * We should use inheritance instead of these special cases
  * for the desktop window.
  */
@@ -117,8 +115,8 @@ static GList *history_list = NULL;
 static GdkPixmap *mini_icon_pixmap;
 static GdkBitmap *mini_icon_mask;
 
-static void nautilus_window_initialize_class          (NautilusWindowClass *klass);
-static void nautilus_window_initialize                (NautilusWindow      *window);
+static void nautilus_window_class_init          (NautilusWindowClass *klass);
+static void nautilus_window_init                (NautilusWindow      *window);
 static void nautilus_window_destroy                   (GtkObject           *object);
 static void nautilus_window_set_arg                   (GtkObject           *object,
 						       GtkArg              *arg,
@@ -136,7 +134,7 @@ static void nautilus_window_unrealize                 (GtkWidget           *widg
 static void cancel_view_as_callback                   (NautilusWindow      *window);
 static void real_add_current_location_to_history_list (NautilusWindow      *window);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusWindow,
+EEL_CLASS_BOILERPLATE (NautilusWindow,
 			      nautilus_window,
 			      BONOBO_TYPE_WINDOW)
 
@@ -150,7 +148,7 @@ unref_mini_icon (void)
 }
 
 static void
-nautilus_window_initialize_class (NautilusWindowClass *klass)
+nautilus_window_class_init (NautilusWindowClass *klass)
 {
 	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
@@ -168,11 +166,11 @@ nautilus_window_initialize_class (NautilusWindowClass *klass)
 	widget_class->unrealize = nautilus_window_unrealize;
 	
 	gtk_object_add_arg_type ("NautilusWindow::app_id",
-				 GTK_TYPE_STRING,
+				 G_TYPE_STRING,
 				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
 				 ARG_APP_ID);
 	gtk_object_add_arg_type ("NautilusWindow::app",
-				 GTK_TYPE_OBJECT,
+				 G_TYPE_OBJECT,
 				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
 				 ARG_APP);
 	
@@ -184,12 +182,12 @@ nautilus_window_initialize_class (NautilusWindowClass *klass)
 
         filename = nautilus_pixmap_file ("nautilus-mini-logo.png");
         if (filename != NULL) {
-                pixbuf = gdk_pixbuf_new_from_file (filename);
+                pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
                 if (pixbuf != NULL) {
                         gdk_pixbuf_render_pixmap_and_mask
 				(pixbuf, &mini_icon_pixmap, &mini_icon_mask,
 				 EEL_STANDARD_ALPHA_THRESHHOLD);
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (pixbuf);
 			g_atexit (unref_mini_icon);
 		}
         	g_free (filename);
@@ -210,11 +208,11 @@ add_sidebar_panel_callback (const char *name,
 	eel_preferences_add_callback_while_alive (preference_key,
 						  sidebar_panels_changed_callback,
 						  callback_data,
-						  GTK_OBJECT (callback_data));
+						  G_OBJECT (callback_data));
 }
 
 static void
-nautilus_window_initialize (NautilusWindow *window)
+nautilus_window_init (NautilusWindow *window)
 {
 	window->details = g_new0 (NautilusWindowDetails, 1);
 
@@ -351,7 +349,7 @@ nautilus_window_clear_status (gpointer callback_data)
 
 	nautilus_window_ui_freeze (window);
 
-	/* FIXME bugzilla.eazel.com 3597:
+	/* FIXME bugzilla.gnome.org 43597:
 	 * Should pass "" or NULL here. This didn't work, then did, now doesn't again.
 	 * When this is fixed in Bonobo we should change this line.
 	 */
@@ -508,89 +506,31 @@ set_initial_window_geometry (NautilusWindow *window)
 	 * is evil. So we choose semi-arbitrary initial and
 	 * minimum widths instead of letting GTK decide.
 	 */
-
+	/* FIXME - the above comment suggests that the size request
+	 * of the content view area is wrong, probably because of
+	 * another stupid set_usize someplace. If someone gets the
+	 * content view area's size request right then we can
+	 * probably remove this broken set_size_request() here.
+	 * - hp@redhat.com
+	 */
+	
 	max_width_for_screen = get_max_forced_width ();
 	max_height_for_screen = get_max_forced_height ();
 
-	gtk_widget_set_usize (GTK_WIDGET (window), 
-			      MIN (NAUTILUS_WINDOW_MIN_WIDTH, 
-			           max_width_for_screen),
-			      MIN (NAUTILUS_WINDOW_MIN_HEIGHT, 
-			           max_height_for_screen));
+	gtk_widget_set_size_request (GTK_WIDGET (window), 
+				     MIN (NAUTILUS_WINDOW_MIN_WIDTH, 
+					  max_width_for_screen),
+				     MIN (NAUTILUS_WINDOW_MIN_HEIGHT, 
+					  max_height_for_screen));
 
 	gtk_window_set_default_size (GTK_WINDOW (window), 
 				     MIN (NAUTILUS_WINDOW_DEFAULT_WIDTH, 
 				          max_width_for_screen), 
 				     MIN (NAUTILUS_WINDOW_DEFAULT_HEIGHT, 
 				          max_height_for_screen));
-
-	gtk_window_set_policy (GTK_WINDOW (window), 
-			       FALSE,  /* don't let window be stretched 
-			                  smaller than usize */
-			       TRUE,   /* do let the window be stretched 
-			                  larger than default size */
-			       FALSE); /* don't shrink the window 
-			                  automatically to fit contents */
-
 }
 
-static void
-menu_bar_no_resize_hack_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
-{
-	/* do nothing */
-}
-
-static void
-menu_bar_no_resize_hack_menu_bar_finder (GtkWidget *child, gpointer data)
-{
-	if (GTK_IS_MENU_BAR (child)) {
-		* (GtkObject **) data = GTK_OBJECT (child);
-	}
-}
-
-/* Since there's only one desktop at a time, we can keep track
- * of our faux-class with a single static.
- */
-static GtkObjectClass *menu_bar_no_resize_hack_class;
-
-static void
-menu_bar_no_resize_hack_class_free (void)
-{
-	g_free (menu_bar_no_resize_hack_class);
-}
-
-/* This call is used to keep the desktop menu bar from resizing.
- * It patches out its class with one where the size_allocate
- * method has been replaced with a no-op.
- */
-static void
-menu_bar_no_resize_hack (NautilusWindow *window)
-{
-	GtkObject *menu_bar;
-	GtkTypeQuery *type_query;
-	
-	menu_bar = NULL;
-	
-	eel_gtk_container_foreach_deep (GTK_CONTAINER (window),
-					     menu_bar_no_resize_hack_menu_bar_finder,
-					     &menu_bar);
-
-	g_return_if_fail (menu_bar != NULL);
-
-	if (menu_bar_no_resize_hack_class == NULL) {
-		g_atexit (menu_bar_no_resize_hack_class_free);
-	}
-	
-	type_query = gtk_type_query (menu_bar->klass->type);
-	g_free (menu_bar_no_resize_hack_class);
-	menu_bar_no_resize_hack_class = g_memdup (menu_bar->klass, type_query->class_size);
-	g_free (type_query);
-	
-	((GtkWidgetClass *) menu_bar_no_resize_hack_class)->size_allocate
-		= menu_bar_no_resize_hack_size_allocate;
-
-	menu_bar->klass = menu_bar_no_resize_hack_class;
-}
+#if GNOME2_CONVERSION_COMPLETE
 
 static gboolean
 location_change_at_idle_callback (gpointer callback_data)
@@ -610,6 +550,7 @@ location_change_at_idle_callback (gpointer callback_data)
 	return FALSE;
 }
 
+
 /* handle bonobo events from the throbber -- since they can come in at
    any time right in the middle of things, defer until idle */
 static void 
@@ -632,6 +573,8 @@ throbber_location_change_request_callback (BonoboListener *listener,
 	}
 }
 
+#endif
+
 /* Add a dummy menu with a "View as ..." item when we first create the
  * view_as_option_menu -- without this the menu draws empty and shrunk,
  * once we populate it it grows and forces the toolbar and all the other
@@ -659,20 +602,20 @@ nautilus_window_constructed (NautilusWindow *window)
 	GtkWidget *view_as_menu_vbox;
   	int sidebar_width;
 	BonoboControl *location_bar_wrapper;
-	EPaned *panel;
 	CORBA_Environment ev;
 	Bonobo_PropertyBag property_bag;
 	
 	/* CORBA and Bonobo setup, which must be done before the location bar setup */
 	window->details->ui_container = bonobo_ui_container_new ();
-	bonobo_ui_container_set_win (window->details->ui_container,
-				     BONOBO_WINDOW (window));
+	bonobo_ui_container_set_engine (window->details->ui_container,
+					bonobo_window_get_ui_engine (BONOBO_WINDOW (window)));
 
 	/* Load the user interface from the XML file. */
 	window->details->shell_ui = bonobo_ui_component_new ("Nautilus Shell");
 	bonobo_ui_component_set_container
 		(window->details->shell_ui,
-		 nautilus_window_get_ui_container (window));
+		 nautilus_window_get_ui_container (window),
+		 NULL);
 
 	nautilus_window_ui_freeze (window);
 
@@ -680,14 +623,9 @@ nautilus_window_constructed (NautilusWindow *window)
 	bonobo_ui_util_set_ui (window->details->shell_ui,
 			       DATADIR,
 			       "nautilus-shell-ui.xml",
-			       "nautilus");
+			       "nautilus", NULL);
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 	
-	/* Load the services part of the user interface too if desired. */
-	if (nautilus_services_are_enabled ()) {
-		nautilus_window_install_service_ui (window);
-	}
-
 	/* set up location bar */
 	location_bar_box = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_container_set_border_width (GTK_CONTAINER (location_bar_box), GNOME_PAD_SMALL);
@@ -695,11 +633,11 @@ nautilus_window_constructed (NautilusWindow *window)
 	window->navigation_bar = nautilus_switchable_navigation_bar_new (window);
 	gtk_widget_show (GTK_WIDGET (window->navigation_bar));
 
-	gtk_signal_connect (GTK_OBJECT (window->navigation_bar), "location_changed",
-			    navigation_bar_location_changed_callback, window);
+	g_signal_connect (window->navigation_bar, "location_changed",
+			    G_CALLBACK (navigation_bar_location_changed_callback), window);
 
-	gtk_signal_connect (GTK_OBJECT (window->navigation_bar), "mode_changed",
-			    navigation_bar_mode_changed_callback, window);
+	g_signal_connect (window->navigation_bar, "mode_changed",
+			    G_CALLBACK (navigation_bar_mode_changed_callback), window);
 
 	gtk_box_pack_start (GTK_BOX (location_bar_box), window->navigation_bar,
 			    TRUE, TRUE, GNOME_PAD_SMALL);
@@ -724,18 +662,18 @@ nautilus_window_constructed (NautilusWindow *window)
 	 */
 	window->zoom_control = nautilus_zoom_control_new ();
 	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_in",
-				   nautilus_window_zoom_in, GTK_OBJECT (window));
+				   G_CALLBACK (nautilus_window_zoom_in), GTK_OBJECT (window));
 	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_out",
-				   nautilus_window_zoom_out, GTK_OBJECT (window));
+				   G_CALLBACK (nautilus_window_zoom_out), GTK_OBJECT (window));
 	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_to_level",
-				   nautilus_window_zoom_to_level, GTK_OBJECT (window));
+				   G_CALLBACK (nautilus_window_zoom_to_level), GTK_OBJECT (window));
 	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_to_fit",
-				   nautilus_window_zoom_to_fit, GTK_OBJECT (window));
+				   G_CALLBACK (nautilus_window_zoom_to_fit), GTK_OBJECT (window));
 	gtk_box_pack_end (GTK_BOX (location_bar_box), window->zoom_control, FALSE, FALSE, 0);
 	
 	gtk_widget_show (location_bar_box);
 	
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
@@ -745,17 +683,16 @@ nautilus_window_constructed (NautilusWindow *window)
 		set_initial_window_geometry (window);
 	
 		window->content_hbox = nautilus_horizontal_splitter_new ();
-		panel = E_PANED (window->content_hbox);
 		
-		/* FIXME bugzilla.eazel.com 1245: Saved in pixels instead of in %? */
-		/* FIXME bugzilla.eazel.com 1245: No reality check on the value? */
+		/* FIXME bugzilla.gnome.org 41245: Saved in pixels instead of in %? */
+		/* FIXME bugzilla.gnome.org 41245: No reality check on the value? */
 		sidebar_width = eel_preferences_get_integer (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH);
-		e_paned_set_position (E_PANED (window->content_hbox), sidebar_width);
+		gtk_paned_set_position (GTK_PANED (window->content_hbox), sidebar_width);
 	}
 	gtk_widget_show (window->content_hbox);
 	bonobo_window_set_contents (BONOBO_WINDOW (window), window->content_hbox);
 	
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
@@ -763,11 +700,11 @@ nautilus_window_constructed (NautilusWindow *window)
 		/* set up the sidebar */
 		window->sidebar = nautilus_sidebar_new ();
 		gtk_widget_show (GTK_WIDGET (window->sidebar));
-		gtk_signal_connect (GTK_OBJECT (window->sidebar), "location_changed",
-				    go_to_callback, window);
-		e_paned_pack1 (E_PANED (window->content_hbox),
-			       GTK_WIDGET (window->sidebar),
-			       FALSE, FALSE);
+		g_signal_connect (window->sidebar, "location_changed",
+				    G_CALLBACK (go_to_callback), window);
+		gtk_paned_pack1 (GTK_PANED (window->content_hbox),
+				 GTK_WIDGET (window->sidebar),
+				 FALSE, TRUE);
 #if 0
 		bonobo_ui_engine_add_sync (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
 					   sidebar_sync);
@@ -776,7 +713,7 @@ nautilus_window_constructed (NautilusWindow *window)
 	
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
@@ -789,12 +726,6 @@ nautilus_window_constructed (NautilusWindow *window)
 					    STATUS_BAR_PATH, TRUE);
 		nautilus_bonobo_set_hidden (window->details->shell_ui,
 					    MENU_BAR_PATH, TRUE);
-
-		/* FIXME bugzilla.eazel.com 4752:
-		 * If we ever get the unsigned math errors in
-		 * gtk_menu_item_size_allocate fixed this can be removed.
-		 */
-		menu_bar_no_resize_hack (window);
 	}
 
 	/* Wrap the location bar in a control and set it up. */
@@ -818,10 +749,12 @@ nautilus_window_constructed (NautilusWindow *window)
 		CORBA_exception_init (&ev);
 		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
 		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {
+#if GNOME2_CONVERSION_COMPLETE
 			window->details->throbber_location_change_request_listener_id =
 				bonobo_event_source_client_add_listener
 				(property_bag, throbber_location_change_request_callback, 
 				 "Bonobo/Property:change:location", NULL, window); 
+#endif
 			bonobo_object_release_unref (property_bag, NULL);	
 		}
 		CORBA_exception_free (&ev);
@@ -835,7 +768,7 @@ nautilus_window_constructed (NautilusWindow *window)
 	nautilus_window_allow_stop (window, FALSE);
 
 	/* Set up undo manager */
-	nautilus_undo_manager_attach (window->application->undo_manager, GTK_OBJECT (window));	
+	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));	
 
 	/* Set up the sidebar panels. */
 	update_sidebar_panels_from_preferences (window);
@@ -921,10 +854,12 @@ nautilus_window_unrealize (GtkWidget *widget)
 		CORBA_exception_init (&ev);
 		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
 		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {	
+#if GNOME2_CONVERSION_COMPLETE
 			bonobo_event_source_client_remove_listener
 				(property_bag,
 				 window->details->throbber_location_change_request_listener_id,
 				 &ev);
+#endif
 			bonobo_object_release_unref (property_bag, NULL);	
 		}
 		CORBA_exception_free (&ev);
@@ -944,62 +879,66 @@ nautilus_window_destroy (GtkObject *object)
 	
 	window = NAUTILUS_WINDOW (object);
 
-	/* Handle the part of destroy that's private to the view
-	 * management.
-	 */
-	nautilus_window_manage_views_destroy (window);
+	if (window->details != NULL) {
+		/* Handle the part of destroy that's private to the view
+		 * management.
+		 */
+		nautilus_window_manage_views_destroy (window);
 
-	/* Get rid of all callbacks. */
+		/* Get rid of all callbacks. */
+		nautilus_window_set_viewed_file (window, NULL);
+		nautilus_window_remove_bookmarks_menu_callback (window);
+		nautilus_window_remove_go_menu_callback (window);
+		nautilus_window_toolbar_remove_theme_callback (window);
 
-	cancel_view_as_callback (window);
-	nautilus_window_remove_bookmarks_menu_callback (window);
-	nautilus_window_remove_go_menu_callback (window);
-	nautilus_window_toolbar_remove_theme_callback (window);
+		if (window->details->ui_idle_id != 0) {
+			gtk_idle_remove (window->details->ui_idle_id);
+		}
 
-	if (window->details->ui_idle_id != 0) {
-		gtk_idle_remove (window->details->ui_idle_id);
-	}
+		/* Get rid of all owned objects. */
 
-	/* Get rid of all owned objects. */
+		if (window->details->shell_ui != NULL) {
+			bonobo_ui_component_unset_container (window->details->shell_ui, NULL);
+			bonobo_object_unref (BONOBO_OBJECT (window->details->shell_ui));
+		}
 
-	if (window->details->shell_ui != NULL) {
-		bonobo_ui_component_unset_container (window->details->shell_ui);
-		bonobo_object_unref (BONOBO_OBJECT (window->details->shell_ui));
-	}
+		nautilus_file_unref (window->details->viewed_file);
 
-	nautilus_file_unref (window->details->viewed_file);
+		g_list_free (window->sidebar_panels);
 
-	g_list_free (window->sidebar_panels);
-
-	free_stored_viewers (window);
+		free_stored_viewers (window);
 	
-	g_free (window->details->location);
-	eel_g_list_free_deep (window->details->selection);
-	eel_g_list_free_deep (window->details->pending_selection);
+		g_free (window->details->location);
+		eel_g_list_free_deep (window->details->selection);
+		eel_g_list_free_deep (window->details->pending_selection);
 
-	nautilus_window_clear_back_list (window);
-	nautilus_window_clear_forward_list (window);
+		nautilus_window_clear_back_list (window);
+		nautilus_window_clear_forward_list (window);
 
-	if (window->current_location_bookmark != NULL) {
-		gtk_object_unref (GTK_OBJECT (window->current_location_bookmark));
-	}
-	if (window->last_location_bookmark != NULL) {
-		gtk_object_unref (GTK_OBJECT (window->last_location_bookmark));
-	}
+		if (window->current_location_bookmark != NULL) {
+			g_object_unref (window->current_location_bookmark);
+		}
+		if (window->last_location_bookmark != NULL) {
+			g_object_unref (window->last_location_bookmark);
+		}
 	
-	if (window->status_bar_clear_id != 0) {
-		g_source_remove (window->status_bar_clear_id);
-	}
+		if (window->status_bar_clear_id != 0) {
+			g_source_remove (window->status_bar_clear_id);
+		}
 
-	if (window->details->ui_container != NULL) {
-		bonobo_object_unref (BONOBO_OBJECT (window->details->ui_container));
-	}
+		if (window->details->ui_container != NULL) {
+			bonobo_object_unref (BONOBO_OBJECT (window->details->ui_container));
+		}
 
-	if (window->details->location_change_at_idle_id != 0) {
-		gtk_idle_remove (window->details->location_change_at_idle_id);
-	}
+		if (window->details->location_change_at_idle_id != 0) {
+			gtk_idle_remove (window->details->location_change_at_idle_id);
+		}
 
-	g_free (window->details);
+		g_free (window->details->title);
+	
+		g_free (window->details);
+		window->details = NULL;
+	}
 
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
@@ -1012,7 +951,8 @@ nautilus_window_save_geometry (NautilusWindow *window)
         g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	g_return_if_fail (GTK_WIDGET_VISIBLE (window));
 
-        geometry_string = gnome_geometry_string (GTK_WIDGET (window)->window);
+        geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
+
 	nautilus_file_set_metadata (window->details->viewed_file,
 				    NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY,
 				    NULL,
@@ -1048,7 +988,7 @@ nautilus_window_update_launcher (GdkWindow *window)
 	 * to update its launching state */
 	gdk_property_change (GDK_ROOT_PARENT (),
 			     gdk_atom_intern ("_NAUTILUS_LAST_WINDOW_REALIZE_TIME", FALSE),
-			     XA_CARDINAL,
+			     gdk_x11_xatom_to_atom (XA_CARDINAL),
 			     32,
 			     PropModeReplace,
 			     (guchar *) &tmp.tv_sec,
@@ -1186,10 +1126,10 @@ view_as_menu_switch_views_callback (GtkWidget *widget, gpointer data)
 
         window = NAUTILUS_WINDOW (data);
 
-        if (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "extra viewer")) == TRUE) {
+        if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "extra viewer")) == TRUE) {
         	activate_extra_viewer (window);
         } else {
-		viewer_index = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "viewer index"));
+		viewer_index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "viewer index"));
 		activate_nth_short_list_item (window, viewer_index);
         }
 }
@@ -1206,12 +1146,12 @@ create_view_as_menu_item (NautilusWindow *window,
 	menu_item = gtk_menu_item_new_with_label (menu_label);
 	g_free (menu_label);
 
-	gtk_signal_connect (GTK_OBJECT (menu_item),
+	g_signal_connect (menu_item,
 			    "activate",
-			    view_as_menu_switch_views_callback, 
+			    G_CALLBACK (view_as_menu_switch_views_callback),
 			    window);
 
-	gtk_object_set_data (GTK_OBJECT (menu_item),
+	g_object_set_data (G_OBJECT (menu_item),
 			     "viewer index",
 			     GINT_TO_POINTER (index));
 
@@ -1317,7 +1257,7 @@ update_extra_viewer_in_view_as_menus (NautilusWindow *window,
 	/* Add new menu item. */
 	if (id != NULL) {
 		new_menu_item = create_view_as_menu_item (window, window->details->extra_viewer, 0);
-		gtk_object_set_data (GTK_OBJECT (new_menu_item), "extra viewer", GINT_TO_POINTER (TRUE));
+		g_object_set_data (G_OBJECT (new_menu_item), "extra viewer", GINT_TO_POINTER (TRUE));
 		gtk_menu_prepend (GTK_MENU (menu), new_menu_item);
 	}
 
@@ -1416,7 +1356,7 @@ chose_component_callback (NautilusViewIdentifier *identifier, gpointer callback_
 		nautilus_window_set_content_view (window, identifier);
 	}
 	
-	/* FIXME bugzilla.eazel.com 1334: There should be some global
+	/* FIXME bugzilla.gnome.org 41334: There should be some global
 	 * way to signal that the file type associations have changed,
 	 * so that the places that display these lists can react. For
 	 * now, hardwire this case, which is the most obvious one by
@@ -1474,19 +1414,19 @@ view_as_menu_choose_view_callback (GtkWidget *widget, gpointer data)
 static void
 refresh_stored_viewers (NautilusWindow *window)
 {
-	GList *components;
-        GList *node;
+	GList *components, *node, *viewers;
 	NautilusViewIdentifier *identifier;
 
-        free_stored_viewers (window);
-
         components = nautilus_mime_get_short_list_components_for_file (window->details->viewed_file);
+	viewers = NULL;
         for (node = components; node != NULL; node = node->next) {
         	identifier = nautilus_view_identifier_new_from_content_view (node->data);
-        	window->details->short_list_viewers = 
-        		g_list_append (window->details->short_list_viewers, identifier);
+        	viewers = g_list_prepend (viewers, identifier);
         }
 	gnome_vfs_mime_component_list_free (components);
+
+        free_stored_viewers (window);
+	window->details->short_list_viewers = g_list_reverse (viewers);
 }
 
 static void
@@ -1543,9 +1483,9 @@ load_view_as_menus_callback (NautilusFile *file,
 
 	/* Add "View as..." extra bonus choice. */
        	menu_item = gtk_menu_item_new_with_label (_("View as..."));
-        gtk_signal_connect (GTK_OBJECT (menu_item),
+        g_signal_connect (menu_item,
         		    "activate",
-        		    view_as_menu_choose_view_callback,
+        		    G_CALLBACK (view_as_menu_choose_view_callback),
         		    window);
        	gtk_widget_show (menu_item);
        	gtk_menu_append (GTK_MENU (new_menu), menu_item);
@@ -1782,8 +1722,9 @@ nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 	if (window->throbber != CORBA_OBJECT_NIL) {
 		CORBA_exception_init (&ev);
 		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
+
 		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {
-			bonobo_property_bag_client_set_value_gboolean (property_bag, "throbbing", allow, &ev);
+			bonobo_pbclient_set_boolean (property_bag, "throbbing", allow, &ev);
 			bonobo_object_release_unref (property_bag, NULL);
 		}
 		CORBA_exception_free (&ev);
@@ -1795,7 +1736,7 @@ nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 void
 nautilus_send_history_list_changed (void)
 {
-	gtk_signal_emit_by_name (nautilus_signaller_get_current (),
+	g_signal_emit_by_name (nautilus_signaller_get_current (),
 			 	 "history_list_changed");
 }
 
@@ -1826,7 +1767,7 @@ remove_from_history_list (NautilusBookmark *bookmark)
 	/* Remove any older entry for this same item. There can be at most 1. */
 	if (node != NULL) {
 		history_list = g_list_remove_link (history_list, node);
-		gtk_object_unref (node->data);
+		g_object_unref (node->data);
 		g_list_free_1 (node);
 	}
 }
@@ -1848,7 +1789,7 @@ add_to_history_list (NautilusBookmark *bookmark)
 		free_history_list_is_set_up = TRUE;
 	}
 
-	gtk_object_ref (GTK_OBJECT (bookmark));
+	g_object_ref (bookmark);
 	remove_from_history_list (bookmark);
 	history_list = g_list_prepend (history_list, bookmark);
 
@@ -1856,7 +1797,7 @@ add_to_history_list (NautilusBookmark *bookmark)
 	if (extra_count > 0) {
 		history_list = g_list_reverse (history_list);
 		for (index = 0; index < extra_count; ++index) {
-			gtk_object_unref (history_list->data);
+			g_object_unref (history_list->data);
 			history_list = g_list_remove (history_list, history_list->data);
 		}
 		history_list = g_list_reverse (history_list);
@@ -1872,7 +1813,7 @@ nautilus_remove_from_history_list_no_notify (const char *uri)
 
 	bookmark = nautilus_bookmark_new (uri, "");
 	remove_from_history_list (bookmark);
-	gtk_object_unref (GTK_OBJECT (bookmark));
+	g_object_unref (bookmark);
 }
 
 static void
@@ -1955,9 +1896,8 @@ nautilus_window_display_error (NautilusWindow *window, const char *error_msg)
 {
 	GtkWidget *dialog;
 	
-	dialog = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR, _("Close"), NULL);
-	gnome_dialog_set_close (GNOME_DIALOG (dialog), TRUE);
-	gnome_dialog_set_default (GNOME_DIALOG (dialog), 0);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window), 0, GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE, error_msg, NULL);
 	gtk_widget_show (dialog);
 }
 
@@ -1987,17 +1927,17 @@ nautilus_window_set_content_view_widget (NautilusWindow *window,
 		 */
 		nautilus_window_ui_update (window);
 
-		/* FIXME bugzilla.eazel.com 1243: 
+		/* FIXME bugzilla.gnome.org 41243: 
 		 * We should use inheritance instead of these special cases
 		 * for the desktop window.
 		 */
-		if (!E_IS_PANED (window->content_hbox)) {
+		if (!GTK_IS_PANED (window->content_hbox)) {
 			gtk_container_add (GTK_CONTAINER (window->content_hbox),
 					   GTK_WIDGET (new_view));
 		} else {
-			e_paned_pack2 (E_PANED (window->content_hbox),
-				       GTK_WIDGET (new_view),
-				       TRUE, TRUE);
+			gtk_paned_pack2 (GTK_PANED (window->content_hbox),
+					 GTK_WIDGET (new_view),
+					 TRUE, TRUE);
 		}
 	}
 
@@ -2132,28 +2072,19 @@ nautilus_window_hide_sidebar (NautilusWindow *window)
 	if (window->sidebar == NULL) {
 		return;
 	}
-	gtk_widget_hide (GTK_WIDGET (window->sidebar));
-	if (window->content_hbox != NULL) {
-		e_paned_set_position (E_PANED (window->content_hbox), 0);
-	}
+	nautilus_horizontal_splitter_collapse
+		(NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
 	nautilus_window_update_show_hide_menu_items (window);
 }
 
 void 
 nautilus_window_show_sidebar (NautilusWindow *window)
 {
-	GtkWidget *widget;
-
 	if (window->sidebar == NULL) {
 		return;
 	}
-	widget = GTK_WIDGET (window->sidebar);
-	gtk_widget_show (widget);
-	if (window->content_hbox != NULL) {
-		e_paned_set_position (E_PANED (window->content_hbox), widget->allocation.width);
-		/* Make sure sidebar is not in collapsed form also */
-		nautilus_horizontal_splitter_expand (NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
-	}
+	nautilus_horizontal_splitter_expand
+		(NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
 	nautilus_window_update_show_hide_menu_items (window);
 }
 
@@ -2162,7 +2093,8 @@ nautilus_window_sidebar_showing (NautilusWindow *window)
 {
 	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), FALSE);
 
-	return window->sidebar != NULL && GTK_WIDGET_VISIBLE (window->sidebar);
+	return GTK_IS_PANED (window->content_hbox)
+		&& gtk_paned_get_position (GTK_PANED (window->content_hbox)) != 0;
 }
 
 void 
@@ -2272,13 +2204,28 @@ void
 nautilus_window_set_viewed_file (NautilusWindow *window,
 				 NautilusFile *file)
 {
+	GList *attributes;
+
 	if (window->details->viewed_file == file) {
 		return;
 	}
 
 	nautilus_file_ref (file);
+
 	cancel_view_as_callback (window);
 	cancel_chose_component_callback (window);
+
+	if (window->details->viewed_file != NULL) {
+		nautilus_file_monitor_remove (window->details->viewed_file,
+					      window);
+	}
+
+	if (file != NULL) {
+		attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME);
+		nautilus_file_monitor_add (file, window, attributes);
+		g_list_free (attributes);
+	}
+
 	nautilus_file_unref (window->details->viewed_file);
 	window->details->viewed_file = file;
 }
